==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/client/content/decoration/girder/GirderWrenchBehaviorHandler.java <==
package com.zurrtum.create.client.content.decoration.girder;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.catnip.data.Pair;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.catnip.theme.Color;
import com.zurrtum.create.client.catnip.outliner.Outliner;
import com.zurrtum.create.content.decoration.girder.GirderWrenchBehavior;
import java.util.Arrays;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_638;

public class GirderWrenchBehaviorHandler {
    public static void tick(class_310 mc) {
        if (mc.field_1724 == null || mc.field_1687 == null || !(mc.field_1765 instanceof class_3965 result))
            return;

        class_638 world = mc.field_1687;
        class_2338 pos = result.method_17777();
        class_1657 player = mc.field_1724;
        class_1799 heldItem = player.method_6047();

        if (player.method_5715())
            return;

        if (!world.method_8320(pos).method_27852(AllBlocks.METAL_GIRDER))
            return;

        if (!heldItem.method_31574(AllItems.WRENCH))
            return;

        Pair<class_2350, GirderWrenchBehavior.Action> dirPair = GirderWrenchBehavior.getDirectionAndAction(result, world, pos);
        if (dirPair == null)
            return;

        class_243 center = VecHelper.getCenterOf(pos);
        class_243 edge = center.method_1019(class_243.method_24954(dirPair.getFirst().method_62675()).method_1021(0.4));
        class_2350.class_2351[] axes = Arrays.stream(Iterate.axes).filter(axis -> axis != dirPair.getFirst().method_10166()).toArray(class_2350.class_2351[]::new);

        double normalMultiplier = dirPair.getSecond() == GirderWrenchBehavior.Action.PAIR ? 4 : 1;
        class_243 corner1 = edge.method_1019(class_243.method_24954(class_2350.method_10169(axes[0], class_2350.class_2352.field_11056).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(class_2350.method_10169(axes[1], class_2350.class_2352.field_11056).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(dirPair.getFirst().method_62675()).method_1021(0.1 * normalMultiplier));

        normalMultiplier = dirPair.getSecond() == GirderWrenchBehavior.Action.HORIZONTAL ? 9 : 2;
        class_243 corner2 = edge.method_1019(class_243.method_24954(class_2350.method_10169(axes[0], class_2350.class_2352.field_11060).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(class_2350.method_10169(axes[1], class_2350.class_2352.field_11060).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(dirPair.getFirst().method_10153().method_62675()).method_1021(0.1 * normalMultiplier));

        Outliner.getInstance().showAABB("girderWrench", new class_238(corner1, corner2)).lineWidth(1 / 32f).colored(new Color(127, 127, 127));
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/content/decoration/girder/GirderWrenchBehaviorHandler.java <==
package com.zurrtum.create.client.content.decoration.girder;

import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.catnip.data.Pair;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.catnip.theme.Color;
import com.zurrtum.create.client.catnip.outliner.Outliner;
import com.zurrtum.create.content.decoration.girder.GirderWrenchBehavior;
import java.util.Arrays;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_638;

public class GirderWrenchBehaviorHandler {
    public static void tick(class_310 mc) {
        if (mc.field_1724 == null || mc.field_1687 == null || !(mc.field_1765 instanceof class_3965 result))
            return;

        class_638 world = mc.field_1687;
        class_2338 pos = result.method_17777();
        class_1657 player = mc.field_1724;
        class_1799 heldItem = player.method_6047();

        if (player.method_5715())
            return;

        if (!world.method_8320(pos).method_27852(AllBlocks.METAL_GIRDER))
            return;

        if (!heldItem.method_31574(AllItems.WRENCH))
            return;

        Pair<class_2350, GirderWrenchBehavior.Action> dirPair = GirderWrenchBehavior.getDirectionAndAction(result, world, pos);
        if (dirPair == null)
            return;

        class_243 center = VecHelper.getCenterOf(pos);
        class_243 edge = center.method_1019(class_243.method_24954(dirPair.getFirst().method_62675()).method_1021(0.4));
        class_2350.class_2351[] axes = Arrays.stream(Iterate.axes).filter(axis -> axis != dirPair.getFirst().method_10166()).toArray(class_2350.class_2351[]::new);

        double normalMultiplier = dirPair.getSecond() == GirderWrenchBehavior.Action.PAIR ? 4 : 1;
        class_243 corner1 = edge.method_1019(class_243.method_24954(class_2350.method_10169(axes[0], class_2350.class_2352.field_11056).method_62675())
                .method_1021(0.3))
            .method_1019(class_243.method_24954(class_2350.method_10169(axes[1], class_2350.class_2352.field_11056).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(dirPair.getFirst().method_62675()).method_1021(0.1 * normalMultiplier));

        normalMultiplier = dirPair.getSecond() == GirderWrenchBehavior.Action.HORIZONTAL ? 9 : 2;
        class_243 corner2 = edge.method_1019(class_243.method_24954(class_2350.method_10169(axes[0], class_2350.class_2352.field_11060).method_62675())
                .method_1021(0.3))
            .method_1019(class_243.method_24954(class_2350.method_10169(axes[1], class_2350.class_2352.field_11060).method_62675()).method_1021(0.3))
            .method_1019(class_243.method_24954(dirPair.getFirst().method_10153().method_62675()).method_1021(0.1 * normalMultiplier));

        Outliner.getInstance().showAABB("girderWrench", new class_238(corner1, corner2)).lineWidth(1 / 32f).colored(new Color(127, 127, 127));
    }
}
